"""Log Lens - Lightweight CLI for analyzing Apache/Nginx server logs."""

__version__ = "0.4.0"
__author__ = "KnowOneActual"
__description__ = "Lightweight CLI for analyzing Apache/Nginx server logs"

__all__ = ["__version__", "__author__", "__description__"]
